@@ -1,8 +1,9 @@
 #---------------------------------------------------------------------------------#
 
-import enterpriseattack
 import logging
 
+import enterpriseattack
+
 #---------------------------------------------------------------------------------#
 # Software class:
 #---------------------------------------------------------------------------------#
@@ -13,7 +14,10 @@ class Software:
         self.id_lookup = id_lookup
         self.attack_objects = attack_objects
         
-        self.id = enterpriseattack.utils.expand_external(kwargs.get('external_references'), 'external_id')
+        self.id = enterpriseattack.utils.expand_external(
+            kwargs.get('external_references'),
+            'external_id'
+        )
         self.mid = kwargs.get('id')
         self.created = kwargs.get('created')
         self.modified = kwargs.get('modified')
@@ -22,8 +26,13 @@ class Software:
         self.name = kwargs.get('name')
         self.type = kwargs.get('type')
         self.description = kwargs.get('description')
-        self.url = enterpriseattack.utils.expand_external(kwargs.get('external_references'), 'url')
-        self.references = enterpriseattack.utils.obtain_sources(kwargs.get('external_references'))
+        self.url = enterpriseattack.utils.expand_external(
+            kwargs.get('external_references'),
+            'url'
+        )
+        self.references = enterpriseattack.utils.obtain_sources(
+            kwargs.get('external_references')
+        )
         self.labels = kwargs.get('labels')
         self.platforms = kwargs.get('x_mitre_platforms')
         self.revoked = kwargs.get('revoked')
@@ -43,9 +52,31 @@ class Software:
             for target_id in self.relationships.get(self.mid):
                 if target_id.startswith('attack-pattern'):
                     if self.id_lookup.get(target_id):
-                        techniques_.append(Technique(self.attack_objects, self.relationships, self.id_lookup, **self.id_lookup[target_id]))
+                        techniques_.append(
+                            Technique(
+                                self.attack_objects,
+                                self.relationships,
+                                self.id_lookup,
+                                **self.id_lookup[target_id]
+                            )
+                        )
         return techniques_
 
+    #---------------------------------------------------------------------------------#
+    # Access Tactics for each Software object:
+    #---------------------------------------------------------------------------------#
+
+    @property
+    def tactics(self):
+
+        tactics_ = []
+
+        for technique in self.techniques:
+            if technique.tactics:
+                for tactic in technique.tactics:
+                    tactics_.append(tactic)
+        return tactics_
+
     #---------------------------------------------------------------------------------#
     # Access Groups for each Software object:
     #---------------------------------------------------------------------------------#
@@ -60,7 +91,14 @@ class Software:
             for target_id in self.relationships.get(self.mid):
                 if target_id.startswith('intrusion-set'):
                     if self.id_lookup.get(target_id):
-                        groups_.append(Group(self.attack_objects, self.relationships, self.id_lookup, **self.id_lookup[target_id]))
+                        groups_.append(
+                            Group(
+                                self.attack_objects,
+                                self.relationships,
+                                self.id_lookup,
+                                **self.id_lookup[target_id]
+                            )
+                        )
         return groups_
 
     #---------------------------------------------------------------------------------#
@@ -84,6 +122,7 @@ class Software:
                 "labels": self.labels,
                 "groups": [group.name for group in self.groups],
                 "techniques": [technique.name for technique in self.techniques],
+                "tactics": [tactic.name for tactic in self.tactics],
                 "platforms": self.platforms,
                 "deprecated": self.deprecated,
                 "revoked": self.revoked
